@@ -1,35 +1,119 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::FindDev;
-BEGIN {
-  $Path::FindDev::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::FindDev::VERSION = '0.4.2';
-}
-
+$Path::FindDev::VERSION = '0.5.0';
 # ABSTRACT: Find a development path somewhere in an upper hierarchy.
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 use Sub::Exporter -setup => { exports => [ find_dev => \&_build_find_dev, ] };
 
 
-sub _build_find_dev {
-  my ( $class, $name, $arg ) = @_;
 
-  my $object;
+
+
+
+
+
+
+
+
+
+sub _build_find_dev {
+  my ( undef, undef, $arg ) = @_;
+
+  my $finddev_object;
   return sub {
     my ($path) = @_;
-    $object ||= do {
+    $finddev_object ||= do {
       require Path::FindDev::Object;
       Path::FindDev::Object->new($arg);
     };
-    return $object->find_dev($path);
-    }
+    return $finddev_object->find_dev($path);
+  };
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 *find_dev = _build_find_dev( __PACKAGE__, 'find_dev', {} );
 
 1;
@@ -46,7 +130,7 @@ Path::FindDev - Find a development path somewhere in an upper hierarchy.
 
 =head1 VERSION
 
-version 0.4.2
+version 0.5.0
 
 =head1 DESCRIPTION
 
@@ -140,7 +224,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
